pilot.api.data.api.PilotDataDescription

Package pilot :: Package api :: Package data :: Module api :: Class PilotDataDescription |

# Class PilotDataDescription

source code

PilotDataDescription (PDD).

Dictionary based description containing reference to resource for Pilot Data.

Example:

       {
       'service_url': "ssh://localhost/tmp/pilotstore/",
       'size':100,

       # Affinity
       'affinity_datacenter_label',    # pilot stores sharing the same label are located in the same data center
       'affinity_machine_label',       # pilot stores sharing the same label are located on the same machine
       }

Alternatively, a regular Python dictionary can be used.

Instance Methods
    new empty dictionary
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__setattr__(self, attr, value) x.__setattr__('name', value) <==> x.name = value | source code
__getattr__(self, attr) | source code
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__str__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Returns:
    new empty dictionary
Overrides: object.__init__ (inherited documentation)

### __setattr__(self, attr, value) | source code
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)